@@ -3,7 +3,7 @@ Setup the basic connection things
 """
 
 #set the base url of the SPONGE-web API
-api_url_base = 'http://10.162.163.20:5000/'
+api_url_base = 'https://exbio.wzw.tum.de/sponge-api/'
 
 #set up the HTTP request headers the way the API docs describe
 headers = {'Content-Type': 'application/json'}
\ No newline at end of file
